%global _hardened_build 1
%global softhsm_module "SoftHSM PKCS #11 Module"

Summary: Software version of a PKCS#11 Hardware Security Module
Name: softhsm
Version: 2.6.1
Release: 4%{?dist}
License: BSD
Url: http://www.opendnssec.org/
Source: http://dist.opendnssec.org/source/%{name}-%{version}.tar.gz
Source1: http://dist.opendnssec.org/source/%{name}-%{version}.tar.gz.sig

Patch3000: softhsm-2.6.1-rh1831086-exit.patch
Patch3001: softhsm-openssl3-tests.patch

BuildRequires: make gcc-c++, pkgconfig, p11-kit-devel
BuildRequires: openssl-devel >= 1.0.1k-6, sqlite-devel >= 3.4.2, cppunit-devel
Requires(pre): shadow-utils
Requires: p11-kit openssl-libs >= 1.0.1k-6

%description
OpenDNSSEC is providing a software implementation of a generic cryptographic device 
with a PKCS#11 interface, the SoftHSM. SoftHSM is designed to meet the requirements 
of OpenDNSSEC, but can also work together with other cryptographic products because 
of the PKCS#11 interface.

%package devel
Summary: Development package of softhsm that includes the header files
Requires: %{name} = %{version}-%{release}, openssl-devel, sqlite-devel

%description devel
The devel package contains the libsofthsm include files

%prep
%autosetup -p1 -n %{name}-%{version}
sed -i 's:full_libdir/softhsm:full_libdir:g' configure

%build
# enable LTO will cause testsuite failure
%define _lto_cflags %{nil}
%configure --libdir=%{_libdir}/pkcs11 --with-openssl=%{_prefix} --enable-ecc --enable-eddsa --disable-gost \
           --with-migrate --enable-visibility --with-p11-kit=%{_datadir}/p11-kit/modules/

%make_build

%check
make check

%install
rm -rf %{buildroot}
%make_install

rm %{buildroot}/%{_sysconfdir}/softhsm2.conf.sample
rm -f %{buildroot}/%{_libdir}/pkcs11/*a
mkdir -p %{buildroot}%{_includedir}/softhsm
cp src/lib/*.h %{buildroot}%{_includedir}/softhsm
mkdir -p %{buildroot}/%{_sharedstatedir}/softhsm/tokens

mkdir -p %{buildroot}/%{_libdir}/softhsm/
ln -s ../pkcs11/libsofthsm2.so %{buildroot}/%{_libdir}/softhsm/libsofthsm.so
( cd  %{buildroot}/%{_libdir} ; ln -s pkcs11/libsofthsm2.so)

%files
%license LICENSE
%doc README.md NEWS
%config(noreplace) %{_sysconfdir}/softhsm2.conf
%{_bindir}/*
%dir %{_libdir}/softhsm
%{_libdir}/pkcs11/libsofthsm2.so
%{_libdir}/libsofthsm2.so
%{_libdir}/softhsm/libsofthsm.so
%attr(0664,root,root) %{_datadir}/p11-kit/modules/softhsm2.module
%attr(0750,ods,ods) %dir %{_sharedstatedir}/softhsm
%attr(1770,ods,ods) %dir %{_sharedstatedir}/softhsm/tokens
%{_mandir}/*/*

%files devel
%attr(0755,root,root) %dir %{_includedir}/softhsm
%{_includedir}/softhsm/*.h

%pre
getent group ods >/dev/null || groupadd -r ods
getent passwd ods >/dev/null || \
    useradd -r -g ods -d %{_sharedstatedir}/softhsm -s /sbin/nologin \
    -c "softhsm private keys owner" ods
exit 0

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Nov 29 2022 Xin Cheng <denisecheng@tencent.com> - 2.6.1-1
- package init.
